@@ -18,3 +18,17 @@
 #' }
 #' @source \url{https://www.oecd.org/pisa/data/}
 "pisa"
+
+#' Income of parents and children
+#'
+#' An artificial dataset containing income of children and their parents together
+#' with some information about them. 
+#'
+#' @format A data frame with 3894 rows and 4 variables:
+#' \describe{
+#'   \item{c_faminc}{Family income of a child}
+#'   \item{p_faminc}{Family income of parent}
+#'   \item{gender}{Gender}
+#'   \item{race}{Race: hisp (Hispanic), black or neither}
+#' }
+"parent_child_income"
\ No newline at end of file
